==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/sbp.pl <==
{
  am_pm_abbreviated => [
    "Lwamilawu",
    "Pashamihe",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sbp",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Mul",
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "M",
  ],
  day_format_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Alahamisi",
    "Ijumaa",
    "Jumamosi",
    "Mulungu",
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Mul",
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "M",
  ],
  day_stand_alone_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Alahamisi",
    "Ijumaa",
    "Jumamosi",
    "Mulungu",
  ],
  era_abbreviated => [
    "AK",
    "PK",
  ],
  era_narrow => [
    "AK",
    "PK",
  ],
  era_wide => [
    "Ashanali uKilisito",
    "Pamwandi ya Kilisto",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sangu",
  month_format_abbreviated => [
    "Mup",
    "Mwi",
    "Msh",
    "Mun",
    "Mag",
    "Muj",
    "Msp",
    "Mpg",
    "Mye",
    "Mok",
    "Mus",
    "Muh",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Mupalangulwa",
    "Mwitope",
    "Mushende",
    "Munyi",
    "Mushende Magali",
    "Mujimbi",
    "Mushipepo",
    "Mupuguto",
    "Munyense",
    "Mokhu",
    "Musongandembwe",
    "Muhaano",
  ],
  month_stand_alone_abbreviated => [
    "Mup",
    "Mwi",
    "Msh",
    "Mun",
    "Mag",
    "Muj",
    "Msp",
    "Mpg",
    "Mye",
    "Mok",
    "Mus",
    "Muh",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Mupalangulwa",
    "Mwitope",
    "Mushende",
    "Munyi",
    "Mushende Magali",
    "Mujimbi",
    "Mushipepo",
    "Mupuguto",
    "Munyense",
    "Mokhu",
    "Musongandembwe",
    "Muhaano",
  ],
  name => "Sangu",
  native_language => "Ishisangu",
  native_name => "Ishisangu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  quarter_stand_alone_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/sbp.pl <==
{
  am_pm_abbreviated => [
    "Lwamilawu",
    "Pashamihe",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "y MMMM",
    yMMMd => "MMM d y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sbp",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Mul",
  ],
  day_format_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "M",
  ],
  day_format_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Alahamisi",
    "Ijumaa",
    "Jumamosi",
    "Mulungu",
  ],
  day_stand_alone_abbreviated => [
    "Jtt",
    "Jnn",
    "Jtn",
    "Alh",
    "Iju",
    "Jmo",
    "Mul",
  ],
  day_stand_alone_narrow => [
    "J",
    "J",
    "J",
    "A",
    "I",
    "J",
    "M",
  ],
  day_stand_alone_wide => [
    "Jumatatu",
    "Jumanne",
    "Jumatano",
    "Alahamisi",
    "Ijumaa",
    "Jumamosi",
    "Mulungu",
  ],
  era_abbreviated => [
    "AK",
    "PK",
  ],
  era_narrow => [
    "AK",
    "PK",
  ],
  era_wide => [
    "Ashanali uKilisito",
    "Pamwandi ya Kilisto",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sangu",
  month_format_abbreviated => [
    "Mup",
    "Mwi",
    "Msh",
    "Mun",
    "Mag",
    "Muj",
    "Msp",
    "Mpg",
    "Mye",
    "Mok",
    "Mus",
    "Muh",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Mupalangulwa",
    "Mwitope",
    "Mushende",
    "Munyi",
    "Mushende Magali",
    "Mujimbi",
    "Mushipepo",
    "Mupuguto",
    "Munyense",
    "Mokhu",
    "Musongandembwe",
    "Muhaano",
  ],
  month_stand_alone_abbreviated => [
    "Mup",
    "Mwi",
    "Msh",
    "Mun",
    "Mag",
    "Muj",
    "Msp",
    "Mpg",
    "Mye",
    "Mok",
    "Mus",
    "Muh",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Mupalangulwa",
    "Mwitope",
    "Mushende",
    "Munyi",
    "Mushende Magali",
    "Mujimbi",
    "Mushipepo",
    "Mupuguto",
    "Munyense",
    "Mokhu",
    "Musongandembwe",
    "Muhaano",
  ],
  name => "Sangu",
  native_language => "Ishisangu",
  native_name => "Ishisangu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  quarter_stand_alone_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
